@@ -4,7 +4,7 @@
 modname = 'vcsfile'
 distname = "cubicweb-%s" % modname
 
-numversion = (1, 12, 3)
+numversion = (1, 13, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -47,5 +47,8 @@ data_files = [
 for dirname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18n', 'migration', 'wdoc'):
     if isdir(dirname):
         data_files.append([join(THIS_CUBE_DIR, dirname), listdir(dirname)])
+data_files.append([join('share', 'doc', distname), [join('scripts', 'hgnotifhook.py')]])
 # Note: here, you'll need to add subdirectories if you want
 # them to be included in the debian package
+
+scripts=('scripts/vcsfile-notifbroker',)
