@@ -75,7 +75,7 @@ def repository_handler(repoent):
             return repohdlr
 
 
-def import_content(session, commitevery=10, raise_on_error=False):
+def import_content(session, commitevery=1000, raise_on_error=False):
     """synchronize content of known vcs repositories
     """
     for vcsrepo in session.execute(
@@ -179,16 +179,24 @@ def import_revision(session, repoeid, date, **kwargs):
     """import a new revision from a repository"""
     args = {'date': date}
     args['repoeid'] = repoeid
-    for attr in ('revision', 'author', 'description', 'changeset', 'branch'):
+    for attr in ('revision', 'author', 'description', 'changeset', 'branch', 'phase', 'hidden'):
         args[attr] = kwargs.get(attr)
     prevs = kwargs['parents']
     if prevs:
         args['parent'] = prevs[0]
-    reveid = session.execute(queries.new_revision_rql(prevs, True), args)[0][0]
+    precs = kwargs['precursors']
+    if precs:
+        args['precursor'] = precs[0]
+    reveid = session.execute(queries.new_revision_rql(prevs, precs, True), args)[0][0]
+    # complete other parents & precursors relations
     if len(prevs) > 1:
         for preveid in prevs[1:]:
             session.execute('SET R parent_revision PR WHERE R eid %(r)s, PR eid %(pr)s',
                             {'r': reveid, 'pr': preveid})
+    if len(precs) > 1:
+        for preceid in precs[1:]:
+            session.execute('SET R obsoletes PREC WHERE R eid %(r)s, PREC eid %(pr)s',
+                            {'r': reveid, 'pr': preceid})
     return reveid
 
 def import_versioned_file(session, repoeid, date, directory, name):
