@@ -16,6 +16,7 @@ from cubicweb.predicates import is_instance
 from cubicweb.entities import AnyEntity, fetch_config, adapters
 
 from cubes.vcsfile import queries
+from cubes.vcsfile.hooks import repo_cache_dir
 
 def rql_revision_content(repoeid, revnum, branch=None):
     """return rql query to get the repository content at a given revision"""
@@ -48,6 +49,21 @@ class Repository(AnyEntity):
     fetch_attrs, cw_fetch_order = fetch_config(['source_url', 'title', 'subpath', 'type'])
     rest_attr = 'eid' # see #XXX, using path cause pb w/ apache redirection
 
+    @property
+    def localcachepath(self):
+        """ return a path to the local repository cache
+
+        Does make sense only for mercurial repositories.
+        The path itself should be enforced unless some late
+        permissions problem arises (in which case this will fail).
+        There is no warranty of an actual repository here.
+        """
+        if self.type != 'mercurial':
+            raise TypeError('.localcachepath only makes sense on a mercurial repository')
+        if self.local_cache is None:
+            raise Exception('%s.local_cache does not exist yet' % self.eid)
+        return osp.join(repo_cache_dir(self._cw.vreg.config), self.local_cache)
+
     def dc_title(self):
         if self.title:
             return self.title
