@@ -160,7 +160,7 @@ class VFModificationDateOp(hook.DataOperationMixIn, hook.Operation):
 
     def precommit_event(self):
         for entity in self.get_data():
-            entity.file.set_attributes(modification_date=entity.rev.creation_date)
+            entity.file.cw_set(modification_date=entity.rev.creation_date)
 
 
 class UpdateVFModificationDateHook(hook.Hook):
@@ -429,33 +429,21 @@ class ClassifyVersionedFileHook(hook.Hook):
     category = 'autoset'
 
     def __call__(self):
-        try:
-            rschema = self._cw.vreg.schema['tags']
-            support_tags = ('Tag', self.entity.e_schema) in rschema.rdefs
-        except KeyError:
-            support_tags = False
         try:
             rschema = self._cw.vreg.schema['filed_under']
             support_folders = (self.entity.e_schema, 'Folder') in rschema.rdefs
         except KeyError:
             support_folders = False
-        if not (support_tags or support_folders):
+        if not support_folders:
             return
         for directory in self.entity.directory.split(os.sep):
             if not directory:
                 continue
-            if support_tags:
-                rset = self._cw.execute('Tag X WHERE X name %(name)s',
-                                       {'name': directory})
-                if rset:
-                    self._cw.execute('SET T tags X WHERE X eid %(x)s, T eid %(t)s',
-                                    {'x': self.entity.eid, 't': rset[0][0]})
-            if support_folders:
-                rset = self._cw.execute('Folder X WHERE X name %(name)s',
-                                       {'name': directory})
-                if rset:
-                    self._cw.execute('SET X filed_under F WHERE X eid %(x)s, F eid %(f)s',
-                                    {'x': self.entity.eid, 'f': rset[0][0]})
+            rset = self._cw.execute('Folder X WHERE X name %(name)s',
+                                   {'name': directory})
+            if rset:
+                self._cw.execute('SET X filed_under F WHERE X eid %(x)s, F eid %(f)s',
+                                {'x': self.entity.eid, 'f': rset[0][0]})
 
 
 def _refresh_repos(repo, eids=None, bridge=bridge):
@@ -522,3 +510,31 @@ class RefreshRepoService(Service):
 
     def call(self, eids=None):
         _refresh_repos(self._cw.repo, eids)
+
+
+class VCSRepoNotifHook(hook.Hook):
+    events = ('server_startup',)
+    __regid__ = 'vcsfile_repo_notif_startup'
+    order = 10 # make sure it is loaded "late" (in fact, it must be
+               # loaded after ZMQStartHook but we lack a dependency
+               # system here, see http://www.cubicweb.org/ticket/2900987)
+    def __call__(self):
+        def callback(msg):
+            self.debug('received notification: %s', ' '.join(msg))
+            msg = msg[-1]
+            with self.internal_session() as session:
+                for suffix in ('', '/'):
+                    rset = sessions.execute('Any R WHERE R source_url U, '
+                                            'R source_url LIKE %(u)s',
+                                            {'u': '%/'+msg+suffix})
+                    if rset:
+                        break
+                if rset:
+                    assert len(rset) == 1, 'found multiple repos for "%s"'%msg
+                    eid = rset[0][0]
+                    self.debug('Calling refresh service for repo %s', eid)
+                    session.call_service('refresh_repository', eids=[eid])
+                else:
+                    self.debug('No repo for %s', msg)
+
+        self.repo.app_instances_bus.add_subscription('vcsfile-repo-notif', callback)
