@@ -154,22 +154,22 @@ class HGRepository(repo.VCSRepository):
                 hgcmd.clone(vui, str(url),
                             dest=self.path, stream='compressed', noupdate=True)
             except (util.Abort, urllib2.URLError), ex:
-                raise bridge.VCSException(self.eid, 'url', str(ex))
+                raise bridge.VCSException(self.eid, 'url', '%s (%s)', (ex, url))
         else:
             self.debug('pulling from %s into %s', remove_authinfo(url), self.path)
             try:
                 hgcmd.pull(vui, hg.repository(vui, self.path), source=str(url))
             except (util.Abort, urllib2.URLError), ex:
-                raise bridge.VCSException(self.eid, 'path', str(ex))
+                raise bridge.VCSException(self.eid, 'path', '%s (%s)', (ex, url,))
         if obsolete._enabled:
             # Wait 15s after a pull and re-pull the null revision, to make it
             # less likely we're missing in-flight obsolescence markers.
-            # see #2818315 
+            # see #2818315
             time.sleep(15)
             try:
                 hgcmd.pull(vui, hg.repository(vui, self.path), source=str(url), rev=('null',))
             except (util.Abort, urllib2.URLError), ex:
-                raise bridge.VCSException(self.eid, 'path', str(ex))
+                raise bridge.VCSException(self.eid, 'path', '%s (%s)', (ex, url))
 
     def import_content(self, repoentity, commitevery=1000):
         """import content from the mercurial repository"""
@@ -227,7 +227,7 @@ class HGRepository(repo.VCSRepository):
                         reventity.cw_delete()
                     else:
                         rev = repo[str(reventity.changeset)].rev()
-                        reventity.set_attributes(revision=rev)
+                        reventity.cw_set(revision=rev)
 
                 if session.execute('Revision R WHERE R revision < 0, R from_repository REPO, '
                                        'REPO eid %(reid)s', {'reid': repoentity.eid}):
